==> g2ipmsg-0.9.tar.gz: g2ipmsg-0.9/src/systray.c <==
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include <gnome.h>
#include <glib.h>

#include "interface.h"
#include "support.h"
#include "common.h"

#if GTK_CHECK_VERSION(2,10,0)

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

static void
on_statusIcon_activate(GtkStatusIcon *status_icon,
		       gpointer       user_data) 
{
  dbg_out("here\n");
    on_startBtn_clicked (status_icon,NULL);
}
static void
on_statusIcon_popupmenu(GtkStatusIcon *status_icon,
		       guint          button,
		       guint          activate_time,
		       gpointer       user_data)
{
  dbg_out("here\n");
  gtk_menu_popup(GTK_MENU(create_main_menu()), NULL, NULL, 
		 gtk_status_icon_position_menu, 
		 status_icon, 
		 button,activate_time);		 

}
gboolean 
systray_message_watcher(GtkWidget *status_icon,gboolean is_normal) {
  GtkStatusIcon *icon=(GtkStatusIcon *)status_icon;
  GdkPixbuf *statusIcon_icon_pixbuf=NULL;

  g_assert(icon);

  if (recv_windows_are_stored()) {
      if  (is_normal) {
	statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsg.xpm");
      }else{
	statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsgrev.xpm");
      }
  }else{
    gtk_status_icon_set_blinking(icon,FALSE);
    if (hostinfo_is_ipmsg_absent()) {
      statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsgrev.xpm");
    }else{
      statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsg.xpm");
    }
  }
  if (statusIcon_icon_pixbuf) {
    gtk_status_icon_set_from_pixbuf(icon,statusIcon_icon_pixbuf);
    gdk_pixbuf_unref (statusIcon_icon_pixbuf);
  }

  return TRUE; 
}
static gboolean
systray_event_button_press_event (GtkWidget       *widget,
				  GdkEventButton  *event,
				  gpointer         user_data)
{

  dbg_out("buttonWin: button press: %d\n", event->button);
  switch (event->button) {
  case 1:
    on_startBtn_clicked (GTK_BUTTON(widget),user_data);
  default:	
    return FALSE;
    break;
  }
  return TRUE;
}

GtkWidget *
create_ipmsg_status_icon(void){
  GtkStatusIcon *statusIcon;
  GdkPixbuf *statusIcon_icon_pixbuf;

  statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsg.xpm");
  if (statusIcon_icon_pixbuf)
    {
      statusIcon = gtk_status_icon_new_from_pixbuf(statusIcon_icon_pixbuf);
      gdk_pixbuf_unref (statusIcon_icon_pixbuf);
    }

  g_signal_connect ((gpointer) statusIcon, "activate",
                    G_CALLBACK (on_statusIcon_activate),
                    NULL);
  g_signal_connect ((gpointer) statusIcon, "popup-menu",
                    G_CALLBACK (on_statusIcon_popupmenu),
                    NULL);

  gtk_status_icon_set_tooltip(statusIcon,_("G2ipmsg"));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (statusIcon, statusIcon, "statusIcon");

  return (GtkWidget *)statusIcon;
}
#endif /*  GTK_CHECK_VERSION(2,10,0) */

==> g2ipmsg-0.9.1.tar.gz: g2ipmsg-0.9.1/src/systray.c <==
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>

#include <gnome.h>
#include <glib.h>

#include "interface.h"
#include "support.h"
#include "common.h"

#if GTK_CHECK_VERSION(2,10,0)

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

static void
on_statusIcon_activate(GtkStatusIcon *status_icon,
		       gpointer       user_data) 
{
  dbg_out("here\n");
  /* We need following cast to avoid compiler warnings. */
  on_startBtn_clicked ((GtkButton *)status_icon,NULL);
}
static void
on_statusIcon_popupmenu(GtkStatusIcon *status_icon,
		       guint          button,
		       guint          activate_time,
		       gpointer       user_data)
{
  dbg_out("here\n");
  gtk_menu_popup(GTK_MENU(create_main_menu()), NULL, NULL, 
		 gtk_status_icon_position_menu, 
		 status_icon, 
		 button,activate_time);		 

}
gboolean 
systray_message_watcher(GtkWidget *status_icon,gboolean is_normal) {
  GtkStatusIcon *icon=(GtkStatusIcon *)status_icon;
  GdkPixbuf *statusIcon_icon_pixbuf=NULL;

  g_assert(icon);

  if (recv_windows_are_stored()) {
      if  (is_normal) {
	statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsg.xpm");
      }else{
	statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsgrev.xpm");
      }
  }else{
    gtk_status_icon_set_blinking(icon,FALSE);
    if (hostinfo_is_ipmsg_absent()) {
      statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsgrev.xpm");
    }else{
      statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsg.xpm");
    }
  }
  if (statusIcon_icon_pixbuf) {
    gtk_status_icon_set_from_pixbuf(icon,statusIcon_icon_pixbuf);
    gdk_pixbuf_unref (statusIcon_icon_pixbuf);
  }

  return TRUE; 
}
static gboolean
systray_event_button_press_event (GtkWidget       *widget,
				  GdkEventButton  *event,
				  gpointer         user_data)
{

  dbg_out("buttonWin: button press: %d\n", event->button);
  switch (event->button) {
  case 1:
    on_startBtn_clicked (GTK_BUTTON(widget),user_data);
  default:	
    return FALSE;
    break;
  }
  return TRUE;
}

GtkWidget *
create_ipmsg_status_icon(void){
  GtkStatusIcon *statusIcon;
  GdkPixbuf *statusIcon_icon_pixbuf;

  statusIcon_icon_pixbuf = create_pixbuf ("g2ipmsg/ipmsg.xpm");
  if (statusIcon_icon_pixbuf)
    {
      statusIcon = gtk_status_icon_new_from_pixbuf(statusIcon_icon_pixbuf);
      gdk_pixbuf_unref (statusIcon_icon_pixbuf);
    }

  g_signal_connect ((gpointer) statusIcon, "activate",
                    G_CALLBACK (on_statusIcon_activate),
                    NULL);
  g_signal_connect ((gpointer) statusIcon, "popup-menu",
                    G_CALLBACK (on_statusIcon_popupmenu),
                    NULL);

  gtk_status_icon_set_tooltip(statusIcon,_("G2ipmsg"));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (statusIcon, statusIcon, "statusIcon");

  return (GtkWidget *)statusIcon;
}
#endif /*  GTK_CHECK_VERSION(2,10,0) */
